"""Console script for mtor."""

import click
import sys
import warnings

from .workflows import (
    prescan_workflow,
    image_workflow,
    data_workflow,
    postprocessing_workflow,
)

warnings.filterwarnings("ignore")


@click.command()
@click.argument(
    "folder",
    type=click.Path(
        exists=True,
        file_okay=False,
        dir_okay=True,
        writable=True,
        readable=True,
        resolve_path=True,
        allow_dash=False,
    ),
)
@click.argument("top", type=click.INT)
@click.argument("right", type=click.INT)
@click.argument("bottom", type=click.INT)
@click.argument("left", type=click.INT)
def main(folder, top, right, bottom, left):
    """Console script for analysing mtor images.

    You need to provide the following information:

    \b
    FOLDER  path to the directory containing tif images to analyse
    TOP     top edge position of the ROI in pixels
    RIGHT   right edge position of the ROI in pixels
    BOTTOM  bottom edge position of the ROI in pixels
    LEFT    left edge position of the ROI in pixels
    """

    pw = prescan_workflow(folder, top, right, bottom, left)
    iw = image_workflow(pw.parameters)
    dw = data_workflow(iw.data, iw.parameters)
    fw = postprocessing_workflow(dw.data, dw.parameters)  # noqa: F841

    return 0


if __name__ == "__main__":
    sys.exit(main())  # pragma: no cover
